﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2017 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Collections.Generic;

namespace HeuristicLab.Problems.Instances {
  public class CFSAPData {
    /// <summary>
    /// The name of the instance
    /// </summary>
    public string Name { get; set; }
    /// <summary>
    /// Optional! The description of the instance
    /// </summary>
    public string Description { get; set; }
    /// <summary>
    /// The number of jobs.
    /// </summary>
    public int Jobs { get; set; }
    /// <summary>
    /// The number of nests.
    /// </summary>
    public int Nests { get; set; }
    /// <summary>
    /// The number of machine per nest.
    /// </summary>
    public int[] Machines { get; set; }
    /// <summary>
    /// For each nest, there is a matrix of processing times representing
    /// for each machine (row) and for each job (column) the processing time.
    /// </summary>
    public List<int[][]> ProcessingTimes { get; set; }
    /// <summary>
    /// For each nest, there is a matrix of setup times representing
    /// first dimension: for each machine,
    /// second dimension: for each job (antecedent)
    /// third dimension: for each job (succedent)
    /// the setup time.
    /// A set-up from the job to itself might also occur, for instance when
    /// a cycle is complete and it is the only job at a certain nest.
    /// </summary>
    public List<int[][][]> SetupTimes { get; set; }
  }
}
